/*
** File: lex.l 
** Content: This file contains lex (or flex) lexical analyzer generator code
**          for processing the Well-Known Text format for geometry
**          described in OpenGIS Simle Features for SQL, Revision 1.0
** Author: Kurt Buehler, Open GIS Consortium, Inc.
** Date: 7/27/1998
**
** Revision History:
**     1.0 - Initial Release, 7/27/1998
**     1.1 - Fixed memory leaks by adding free routines, also added new
**           library routine freewkb(), 8/31/98 
**           Contributed by:
**              Robert Power
**              robert.power@cmis.csiro.au   Software Engineer
**              CSIRO Mathematical and Information Sciences
**              Canberra Laboratory
**              PO Box 664      tel: +61 6 216 7039
**              Canberra ACT 2601 AUSTRALIA.   fax: +61 6 216 7112
**              http://www.cmis.csiro.au/sis
**
*/

/*
** Copyright 1998, Open GIS Consortium, Inc.
**
** WHILE THE SOFTWARE IN THIS FILE IS BELIEVED TO BE ACCURATE, 
** THE OPEN GIS CONSORTIUM MAKES NO WARRANTY OF ANY KIND WITH REGARD TO 
** THIS MATERIAL INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
** MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. The Open GIS
** Consortium shall not be liable for errors contained herein or for incidental
** or consequential damages in connection with the furnishing, performance or 
** use of this material.
**
** This document contains information, which is protected by copyright. All 
** Rights Reserved. Any part of this work covered by copyright herein may be 
** reproduced or used in any form or by any means graphic, electronic, or 
** mechanical, including photocopying, recording, taping, or information 
** storage and retrieval systems as long as this copyright notice remains.
**
** RESTRICTED RIGHTS LEGEND. Use, duplication, or disclosure by government is 
** subject to restrictions as set forth in subdivision (c)(1)(ii) of the Right 
** in Technical Data and Computer Software Clause at DFARS 252.227.7013
** 
** OpenGIS(R) is a trademark or registered trademark of Open GIS Consortium, 
** Inc. in the United States and in other countries.
*/

%{
#include <stdlib.h>
#include <string.h>
#include "wkb.h"
#include "grammar.tab.h"
%}
DIGIT     [0-9]
%%
point|POINT {
        yylval.string_val = "POINT";
        return(POINT); 
      }

linestring|LINESTRING {
        yylval.string_val = "LINESTRING";
        return(LINESTRING); 
      }

polygon|POLYGON {
        yylval.string_val = "POLYGON";
        return(POLYGON); 
      }

multipoint|MULTIPOINT {
        yylval.string_val = "MULTIPOINT";
        return(MULTIPOINT); 
      }

multilinestring|MULTILINESTRING {
        yylval.string_val = "MULTILINESTRING";
        return(MULTILINESTRING); 
      }

multipolgon|MULTIPOLYGON {
        yylval.string_val = "MULTIPOLYGON";
        return(MULTIPOLYGON); 
      }

geometrycollection|GEOMETRYCOLLECTION { 
        yylval.string_val = "GEOMETRYCOLLECTION";
        return(GEOMETRYCOLLECTION); 
      }

{DIGIT}+|{DIGIT}+"."{DIGIT}*        { 
        yylval.real_val = atof(yytext);
        return(REAL);
      }

"("  return(LPAREN); 

")"  return(RPAREN); 

","  return(COMMA); 

[ \t\n]+ ;
%%
